package com.lantone.daqe.web;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.lantone.common.api.CommonResult;
import com.lantone.daqe.dto.GetDiseasePageDTO;
import com.lantone.daqe.facade.DiseaseManagementFacade;
import com.lantone.daqe.vo.AddDiseaseVo;
import com.lantone.daqe.vo.DelDiseaseByIdVo;
import com.lantone.daqe.vo.GetDiseasePageVO;
import com.lantone.daqe.vo.UpDiseaseByIdVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @Description: 诊断管理API
 * @author: songxl
 * @time: 2021/7/20 12:39
 */
@RestController
@Api(value = "诊断管理API", tags = { "诊断管理API" })
@RequestMapping("/diseaseManage")
public class DiseaseManagementController {

    @Autowired
    private DiseaseManagementFacade diseaseManagementFacade;

    @ApiOperation(value = "获取诊断分页列表 [by:songxl]")
    @PostMapping("/getDiseasePage")
    public CommonResult<IPage<GetDiseasePageDTO>> getDiseasePage(@RequestBody GetDiseasePageVO getDiseasePageVO) {
        return CommonResult.success(diseaseManagementFacade.getDiseasePage(getDiseasePageVO));
    }


    @ApiOperation(value = "新增诊断 [by:songxl]")
    @PostMapping("/addDisease")
    public CommonResult<Boolean> addDisease(@RequestBody AddDiseaseVo addDiseaseVo) {
        return CommonResult.success(diseaseManagementFacade.addDisease(addDiseaseVo));
    }

    @ApiOperation(value = "修改诊断 [by:songxl]")
    @PostMapping("/upDiseaseById")
    public CommonResult<Boolean> upDiseaseById(@RequestBody UpDiseaseByIdVo upDiseaseByIdVo) {
        return CommonResult.success(diseaseManagementFacade.upDiseaseById(upDiseaseByIdVo));
    }

    @ApiOperation(value = "删除诊断 [by:songxl]")
    @PostMapping("/delDiseaseById")
    public CommonResult<Boolean> delDiseaseById(@RequestBody DelDiseaseByIdVo delDiseaseByIdVo) {
        return CommonResult.success(diseaseManagementFacade.delDiseaseById(delDiseaseByIdVo));
    }
}